# Generated by roxygen2: do not edit by hand

export(dbbinom)
export(dbern)
export(dbetapr)
export(dbhatt)
export(dbnbinom)
export(dbvnorm)
export(dbvpois)
export(dcat)
export(ddgamma)
export(ddirichlet)
export(ddirmnom)
export(ddlaplace)
export(ddnorm)
export(ddunif)
export(ddweibull)
export(dfatigue)
export(dfrechet)
export(dgev)
export(dgompertz)
export(dgpd)
export(dgpois)
export(dgumbel)
export(dhcauchy)
export(dhnorm)
export(dht)
export(dhuber)
export(dinvchisq)
export(dinvgamma)
export(dkumar)
export(dlaplace)
export(dlgser)
export(dlomax)
export(dlst)
export(dmixnorm)
export(dmixpois)
export(dmnom)
export(dmvhyper)
export(dnhyper)
export(dnsbeta)
export(dpareto)
export(dpower)
export(dprop)
export(drayleigh)
export(dsgomp)
export(dskellam)
export(dslash)
export(dtbinom)
export(dtnorm)
export(dtpois)
export(dtriang)
export(dwald)
export(dzib)
export(dzinb)
export(dzip)
export(pbbinom)
export(pbern)
export(pbetapr)
export(pbhatt)
export(pbnbinom)
export(pcat)
export(pdgamma)
export(pdlaplace)
export(pdnorm)
export(pdunif)
export(pdweibull)
export(pfatigue)
export(pfrechet)
export(pgev)
export(pgompertz)
export(pgpd)
export(pgpois)
export(pgumbel)
export(phcauchy)
export(phnorm)
export(pht)
export(phuber)
export(pinvchisq)
export(pinvgamma)
export(pkumar)
export(plaplace)
export(plgser)
export(plomax)
export(plst)
export(pmixnorm)
export(pmixpois)
export(pnhyper)
export(pnsbeta)
export(ppareto)
export(ppower)
export(pprop)
export(prayleigh)
export(psgomp)
export(pslash)
export(ptbinom)
export(ptnorm)
export(ptpois)
export(ptriang)
export(pwald)
export(pzib)
export(pzinb)
export(pzip)
export(qbern)
export(qbetapr)
export(qcat)
export(qdunif)
export(qdweibull)
export(qfatigue)
export(qfrechet)
export(qgev)
export(qgompertz)
export(qgpd)
export(qgumbel)
export(qhcauchy)
export(qhnorm)
export(qht)
export(qhuber)
export(qinvchisq)
export(qinvgamma)
export(qkumar)
export(qlaplace)
export(qlgser)
export(qlomax)
export(qlst)
export(qnhyper)
export(qnsbeta)
export(qpareto)
export(qpower)
export(qprop)
export(qrayleigh)
export(qtbinom)
export(qtlambda)
export(qtnorm)
export(qtpois)
export(qtriang)
export(qzib)
export(qzinb)
export(qzip)
export(rbbinom)
export(rbern)
export(rbetapr)
export(rbhatt)
export(rbnbinom)
export(rbvnorm)
export(rbvpois)
export(rcat)
export(rcatlp)
export(rdgamma)
export(rdirichlet)
export(rdirmnom)
export(rdlaplace)
export(rdnorm)
export(rdunif)
export(rdweibull)
export(rfatigue)
export(rfrechet)
export(rgev)
export(rgompertz)
export(rgpd)
export(rgpois)
export(rgumbel)
export(rhcauchy)
export(rhnorm)
export(rht)
export(rhuber)
export(rinvchisq)
export(rinvgamma)
export(rkumar)
export(rlaplace)
export(rlgser)
export(rlomax)
export(rlst)
export(rmixnorm)
export(rmixpois)
export(rmnom)
export(rmvhyper)
export(rnhyper)
export(rnsbeta)
export(rpareto)
export(rpower)
export(rprop)
export(rrayleigh)
export(rsgomp)
export(rsign)
export(rskellam)
export(rslash)
export(rtbinom)
export(rtlambda)
export(rtnorm)
export(rtpois)
export(rtriang)
export(rwald)
export(rzib)
export(rzinb)
export(rzip)
importFrom(Rcpp,sourceCpp)
importFrom(stats,pgamma)
importFrom(stats,pnorm)
importFrom(stats,qchisq)
importFrom(stats,qgamma)
importFrom(stats,qnorm)
importFrom(stats,rchisq)
importFrom(stats,rgamma)
importFrom(stats,rnorm)
importFrom(stats,rpois)
useDynLib(extraDistr, .registration = TRUE)
